@@ -9,12 +9,14 @@
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 """Test addurls plugin"""
 
+from copy import deepcopy
 import json
 import logging
 import os
 import os.path as op
 import shutil
 import tempfile
+from urllib.parse import urlparse
 
 from unittest.mock import patch
 
@@ -422,12 +424,13 @@ class TestAddurls(object):
     def setup_class(cls):
         mktmp_kws = get_tempfile_kwargs()
         path = tempfile.mkdtemp(**mktmp_kws)
-        create_tree(path,
+        http_root = op.join(path, "srv")
+        create_tree(http_root,
                     {"udir": {x + ".dat" + ver: x + " content"
                               for x in "abcd"
                               for ver in ["", ".v1"]}})
 
-        cls._hpath = HTTPPath(path)
+        cls._hpath = HTTPPath(http_root)
         cls._hpath.start()
         cls.url = cls._hpath.url
 
@@ -446,14 +449,16 @@ class TestAddurls(object):
                      "subdir": "foo",
                      "md5sum": "9b72648021b70b8c522642e4490d7ac3",
                      "size": "9"}]
-        cls.json_file = tempfile.mktemp(suffix=".json", **mktmp_kws)
+        cls.json_file = op.join(path, "test_addurls.json")
         with open(cls.json_file, "w") as jfh:
             json.dump(cls.data, jfh)
 
+        cls.temp_dir = path
+
     @classmethod
     def teardown_class(cls):
         cls._hpath.stop()
-        rmtemp(cls._hpath.path)
+        rmtemp(cls.temp_dir)
 
     @with_tempfile(mkdir=True)
     def test_addurls(self, path):
@@ -485,8 +490,8 @@ class TestAddurls(object):
 
         # Ignore this check if we're faking dates because that disables
         # batch mode.
-        # Also ignore if on Windows as it seems as if a git-annex bug 
-        # leads to separate meta data commits: 
+        # Also ignore if on Windows as it seems as if a git-annex bug
+        # leads to separate meta data commits:
         # https://github.com/datalad/datalad/pull/5202#discussion_r535429704
         if not (dl_cfg.get('datalad.fake-dates') or on_windows):
             # We should have two new commits on the git-annex: one for the
@@ -639,6 +644,21 @@ class TestAddurls(object):
                       "{url}/nofilename/",
                       "{_url0}/{_url_filename}")
 
+    @with_tempfile(mkdir=True)
+    def test_addurls_url_special_key_fail(self, path):
+        ds = Dataset(path).create(force=True)
+
+        res1 = ds.addurls(self.json_file, "{url}", "{_url4}/{_url_filename}",
+                          on_failure="ignore")
+        assert_in("Special key", res1[0]["message"])
+
+        data = self.data.copy()[:1]
+        data[0]["url"] = urlparse(data[0]["url"]).netloc
+        with patch("sys.stdin", new=StringIO(json.dumps(data))):
+            res2 = ds.addurls("-", "{url}", "{_url_basename}",
+                              on_failure="ignore")
+        assert_in("Special key", res2[0]["message"])
+
     @with_tempfile(mkdir=True)
     def test_addurls_metafail(self, path):
         ds = Dataset(path).create(force=True)
@@ -828,7 +848,7 @@ class TestAddurls(object):
         if OLD_EXAMINEKEY and ds.repo.is_managed_branch():
             raise SkipTest("Adjusted branch functionality requires "
                            "more recent `git annex examinekey`")
-        data = self.data.copy()
+        data = deepcopy(self.data)
         for row in data:
             if row["name"] == "b":
                 del row["md5sum"]
